@@ -49,14 +49,12 @@ from autogalaxy import cosmology as cosmo
 from autogalaxy.gui.clicker import Clicker
 from autogalaxy.gui.scribbler import Scribbler
 from autogalaxy.galaxy.galaxy import Galaxy
-from autogalaxy.galaxy.hyper import HyperGalaxy
 from autogalaxy.galaxy.redshift import Redshift
 from autogalaxy.analysis.clump_model import ClumpModel
 from autogalaxy.analysis.clump_model import ClumpModelDisabled
 
 from autogalaxy.quantity.dataset_quantity import DatasetQuantity
 from autogalaxy.quantity.dataset_quantity import SettingsQuantity
-from autogalaxy.hyper import hyper_data
 from autogalaxy.plane.plane import Plane
 from autogalaxy.profiles.geometry_profiles import EllProfile
 from autogalaxy.profiles import (
@@ -89,7 +87,7 @@ from .lens.to_inversion import TracerToInversion
 from .analysis.positions import PositionsLHResample
 from .analysis.positions import PositionsLHPenalty
 from .analysis.preloads import Preloads
-from .analysis.setup import SetupHyper
+from .analysis.setup import SetupAdapt
 from .imaging.imaging import SimulatorImaging
 from .imaging.fit_imaging import FitImaging
 from .imaging.model.analysis import AnalysisImaging
@@ -116,4 +114,4 @@ from autoconf import conf
 
 conf.instance.register(__file__)
 
-__version__ = "2023.3.21.5"
\ No newline at end of file
+__version__ = "2023.7.5.2"
