@@ -15,23 +15,22 @@ from autolens.aggregator.tracer import _tracer_from
 def _fit_imaging_from(
     fit: af.Fit,
     galaxies: List[ag.Galaxy],
-    settings_imaging: aa.SettingsImaging = None,
+    settings_dataset: aa.SettingsImaging = None,
     settings_pixelization: aa.SettingsPixelization = None,
     settings_inversion: aa.SettingsInversion = None,
     use_preloaded_grid: bool = True,
-    use_hyper_scaling: bool = True,
 ) -> FitImaging:
     """
     Returns a `FitImaging` object from a PyAutoFit database `Fit` object and an instance of galaxies from a non-linear
     search model-fit.
 
-    This function adds the `hyper_model_image` and `hyper_galaxy_image_path_dict` to the galaxies before performing the
+    This function adds the `adapt_model_image` and `adapt_galaxy_image_path_dict` to the galaxies before performing the
     fit, if they were used.
 
     Parameters
     ----------
     fit
-        A PyAutoFit database Fit object containing the generators of the results of PyAutoGalaxy model-fits.
+        A PyAutoFit database Fit object containing the generators of the results of model-fits.
     galaxies
         A list of galaxies corresponding to a sample of a non-linear search and model-fit.
 
@@ -41,7 +40,7 @@ def _fit_imaging_from(
         The fit to the imaging dataset computed via an instance of galaxies.
     """
 
-    imaging = _imaging_from(fit=fit, settings_imaging=settings_imaging)
+    dataset = _imaging_from(fit=fit, settings_dataset=settings_dataset)
 
     tracer = _tracer_from(fit=fit, galaxies=galaxies)
 
@@ -53,11 +52,9 @@ def _fit_imaging_from(
     preloads = Preloads(use_w_tilde=False)
 
     if use_preloaded_grid:
-
         sparse_grids_of_planes = fit.value(name="preload_sparse_grids_of_planes")
 
         if sparse_grids_of_planes is not None:
-
             preloads = Preloads(
                 sparse_image_plane_grid_pg_list=sparse_grids_of_planes,
                 use_w_tilde=False,
@@ -70,12 +67,11 @@ def _fit_imaging_from(
                     ]
 
     return FitImaging(
-        dataset=imaging,
+        dataset=dataset,
         tracer=tracer,
         settings_pixelization=settings_pixelization,
         settings_inversion=settings_inversion,
         preloads=preloads,
-        use_hyper_scaling=use_hyper_scaling,
     )
 
 
@@ -83,11 +79,10 @@ class FitImagingAgg(AbstractAgg):
     def __init__(
         self,
         aggregator: af.Aggregator,
-        settings_imaging: Optional[aa.SettingsImaging] = None,
+        settings_dataset: Optional[aa.SettingsImaging] = None,
         settings_pixelization: Optional[aa.SettingsPixelization] = None,
         settings_inversion: Optional[aa.SettingsInversion] = None,
         use_preloaded_grid: bool = True,
-        use_hyper_scaling: bool = True,
     ):
         """
         Wraps a PyAutoFit aggregator in order to create generators of fits to imaging data, corresponding to the
@@ -95,13 +90,12 @@ class FitImagingAgg(AbstractAgg):
         """
         super().__init__(aggregator=aggregator)
 
-        self.settings_imaging = settings_imaging
+        self.settings_dataset = settings_dataset
         self.settings_pixelization = settings_pixelization
         self.settings_inversion = settings_inversion
         self.use_preloaded_grid = use_preloaded_grid
-        self.use_hyper_scaling = use_hyper_scaling
 
-    def make_object_for_gen(self, fit, galaxies) -> FitImaging:
+    def object_via_gen_from(self, fit, galaxies) -> FitImaging:
         """
         Creates a `FitImaging` object from a `ModelInstance` that contains the galaxies of a sample from a non-linear
         search.
@@ -109,7 +103,7 @@ class FitImagingAgg(AbstractAgg):
         Parameters
         ----------
         fit
-            A PyAutoFit database Fit object containing the generators of the results of PyAutoGalaxy model-fits.
+            A PyAutoFit database Fit object containing the generators of the results of model-fits.
         galaxies
             A list of galaxies corresponding to a sample of a non-linear search and model-fit.
 
@@ -122,9 +116,8 @@ class FitImagingAgg(AbstractAgg):
         return _fit_imaging_from(
             fit=fit,
             galaxies=galaxies,
-            settings_imaging=self.settings_imaging,
+            settings_dataset=self.settings_dataset,
             settings_pixelization=self.settings_pixelization,
             settings_inversion=self.settings_inversion,
             use_preloaded_grid=self.use_preloaded_grid,
-            use_hyper_scaling=self.use_hyper_scaling,
         )
