@@ -17,7 +17,7 @@ def _fit_interferometer_from(
     fit: af.Fit,
     galaxies: List[ag.Galaxy],
     real_space_mask: Optional[aa.Mask2D] = None,
-    settings_interferometer: aa.SettingsInterferometer = None,
+    settings_dataset: aa.SettingsInterferometer = None,
     settings_pixelization: aa.SettingsPixelization = None,
     settings_inversion: aa.SettingsInversion = None,
     use_preloaded_grid: bool = True,
@@ -26,13 +26,13 @@ def _fit_interferometer_from(
     Returns a `FitInterferometer` object from a PyAutoFit database `Fit` object and an instance of galaxies from a non-linear
     search model-fit.
 
-    This function adds the `hyper_model_image` and `hyper_galaxy_image_path_dict` to the galaxies before performing the
+    This function adds the `adapt_model_image` and `adapt_galaxy_image_path_dict` to the galaxies before performing the
     fit, if they were used.
 
     Parameters
     ----------
     fit
-        A PyAutoFit database Fit object containing the generators of the results of PyAutoGalaxy model-fits.
+        A PyAutoFit database Fit object containing the generators of the results of model-fits.
     galaxies
         A list of galaxies corresponding to a sample of a non-linear search and model-fit.
 
@@ -41,10 +41,10 @@ def _fit_interferometer_from(
     FitInterferometer
         The fit to the interferometer dataset computed via an instance of galaxies.
     """
-    interferometer = _interferometer_from(
+    dataset = _interferometer_from(
         fit=fit,
         real_space_mask=real_space_mask,
-        settings_interferometer=settings_interferometer,
+        settings_dataset=settings_dataset,
     )
     tracer = _tracer_from(fit=fit, galaxies=galaxies)
 
@@ -56,15 +56,13 @@ def _fit_interferometer_from(
     preloads = Preloads(use_w_tilde=settings_inversion.use_w_tilde)
 
     if use_preloaded_grid:
-
         sparse_grids_of_planes = fit.value(name="preload_sparse_grids_of_planes")
 
         if sparse_grids_of_planes is not None:
-
             preloads = Preloads(sparse_image_plane_grid_pg_list=sparse_grids_of_planes)
 
     return FitInterferometer(
-        dataset=interferometer,
+        dataset=dataset,
         tracer=tracer,
         settings_pixelization=settings_pixelization,
         settings_inversion=settings_inversion,
@@ -76,7 +74,7 @@ class FitInterferometerAgg(AbstractAgg):
     def __init__(
         self,
         aggregator: af.Aggregator,
-        settings_interferometer: Optional[aa.SettingsInterferometer] = None,
+        settings_dataset: Optional[aa.SettingsInterferometer] = None,
         settings_pixelization: Optional[aa.SettingsPixelization] = None,
         settings_inversion: Optional[aa.SettingsInversion] = None,
         use_preloaded_grid: bool = True,
@@ -88,21 +86,21 @@ class FitInterferometerAgg(AbstractAgg):
         """
         super().__init__(aggregator=aggregator)
 
-        self.settings_interferometer = settings_interferometer
+        self.settings_dataset = settings_dataset
         self.settings_pixelization = settings_pixelization
         self.settings_inversion = settings_inversion
         self.use_preloaded_grid = use_preloaded_grid
         self.real_space_mask = real_space_mask
 
-    def make_object_for_gen(self, fit, galaxies) -> FitInterferometer:
+    def object_via_gen_from(self, fit, galaxies) -> FitInterferometer:
         """
-        Creates a `FitInterferometer` object from a `ModelInstance` that contains the galaxies of a sample from a non-linear
-        search.
+        Creates a `FitInterferometer` object from a `ModelInstance` that contains the galaxies of a sample from a
+        non-linear search.
 
         Parameters
         ----------
         fit
-            A PyAutoFit database Fit object containing the generators of the results of PyAutoGalaxy model-fits.
+            A PyAutoFit database Fit object containing the generators of the results of model-fits.
         galaxies
             A list of galaxies corresponding to a sample of a non-linear search and model-fit.
 
@@ -114,7 +112,7 @@ class FitInterferometerAgg(AbstractAgg):
         return _fit_interferometer_from(
             fit=fit,
             galaxies=galaxies,
-            settings_interferometer=self.settings_interferometer,
+            settings_dataset=self.settings_dataset,
             settings_pixelization=self.settings_pixelization,
             settings_inversion=self.settings_inversion,
             use_preloaded_grid=self.use_preloaded_grid,
