@@ -65,12 +65,15 @@ class AnalysisLensing:
         self.positions_likelihood = positions_likelihood
 
     def tracer_via_instance_from(
-        self, instance: af.ModelInstance, profiling_dict: Optional[Dict] = None
+        self,
+        instance: af.ModelInstance,
+        run_time_dict: Optional[Dict] = None,
+        tracer_cls=Tracer,
     ) -> Tracer:
         """
         Create a `Tracer` from the galaxies contained in a model instance.
 
-        If PyAutoFit's profiling tools are used with the analsyis class, this function may receive a `profiling_dict`
+        If PyAutoFit's profiling tools are used with the analsyis class, this function may receive a `run_time_dict`
         which times how long each set of the model-fit takes to perform.
 
         Parameters
@@ -91,7 +94,6 @@ class AnalysisLensing:
         # TODO : A Subhalo class that extends the Galaxy class maybe?
 
         if hasattr(instance.galaxies, "subhalo"):
-
             subhalo_centre = ray_tracing_util.grid_2d_at_redshift_from(
                 galaxies=instance.galaxies,
                 redshift=instance.galaxies.subhalo.redshift,
@@ -102,11 +104,10 @@ class AnalysisLensing:
             instance.galaxies.subhalo.mass.centre = tuple(subhalo_centre.in_list[0])
 
         if hasattr(instance, "clumps"):
-
             return Tracer.from_galaxies(
                 galaxies=instance.galaxies + instance.clumps,
                 cosmology=self.cosmology,
-                profiling_dict=profiling_dict,
+                run_time_dict=run_time_dict,
             )
 
         if hasattr(instance, "cosmology"):
@@ -114,10 +115,10 @@ class AnalysisLensing:
         else:
             cosmology = self.cosmology
 
-        return Tracer.from_galaxies(
+        return tracer_cls.from_galaxies(
             galaxies=instance.galaxies,
             cosmology=cosmology,
-            profiling_dict=profiling_dict,
+            run_time_dict=run_time_dict,
         )
 
     def log_likelihood_positions_overwrite_from(
@@ -143,7 +144,6 @@ class AnalysisLensing:
         else a None is returned to indicate there is no penalty.
         """
         if self.positions_likelihood is not None:
-
             try:
                 return self.positions_likelihood.log_likelihood_function_positions_overwrite(
                     instance=instance, analysis=self
@@ -159,7 +159,7 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLensing):
         positions_likelihood: Optional[
             Union[PositionsLHResample, PositionsLHPenalty]
         ] = None,
-        hyper_dataset_result=None,
+        adapt_result=None,
         cosmology: ag.cosmo.LensingCosmology = ag.cosmo.Planck15(),
         settings_pixelization: aa.SettingsPixelization = None,
         settings_inversion: aa.SettingsInversion = None,
@@ -203,7 +203,7 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLensing):
 
         super().__init__(
             dataset=dataset,
-            hyper_dataset_result=hyper_dataset_result,
+            adapt_result=adapt_result,
             cosmology=cosmology,
             settings_pixelization=settings_pixelization,
             settings_inversion=settings_inversion,
@@ -225,7 +225,6 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLensing):
         )
 
         if os.environ.get("PYAUTOFIT_TEST_MODE") == "1":
-
             self.raise_inversion_positions_likelihood_exception = False
 
     def modify_before_fit(self, paths: af.DirectoryPaths, model: af.Collection):
@@ -235,7 +234,7 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLensing):
 
         This function:
 
-        - Checks that the hyper-dataset is consistent with previous hyper-datasets if the model-fit is being
+        - Checks that the adapt-dataset is consistent with previous adapt-datasets if the model-fit is being
           resumed from a previous run.
 
         - Checks the model and raises exceptions if certain critieria are not met.
@@ -257,7 +256,6 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLensing):
         self.raise_exceptions(model=model)
 
     def raise_exceptions(self, model):
-
         if ag.util.model.has_pixelization_from(model=model):
             if (
                 self.positions_likelihood is None
@@ -346,19 +344,18 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLensing):
             The PyAutoFit paths object which manages all paths, e.g. where the non-linear search outputs are stored,
             visualization and the pickled objects used by the aggregator output by this function.
         result
-            The result of a lens model fit, including the non-linear search, samples and maximum likelihood tracer.
+            The result of a model fit, including the non-linear search, samples and maximum likelihood tracer.
         """
 
         mesh_list = ag.util.model.mesh_list_from(model=result.model)
 
         if len(mesh_list) > 0:
-
             paths.save_object(
                 "preload_sparse_grids_of_planes",
                 result.max_log_likelihood_fit.tracer_to_inversion.sparse_image_plane_grid_pg_list,
             )
 
-        if conf.instance["general"]["hyper"]["stochastic_outputs"]:
+        if conf.instance["general"]["adapt"]["stochastic_outputs"]:
             if len(mesh_list) > 0:
                 for mesh in mesh_list:
                     if mesh.is_stochastic:
