@@ -1,12 +1,7 @@
-import json
 import logging
 import numpy as np
-import os
-import time
-from typing import Dict, Optional
-from os import path
+from typing import Dict, Optional, Tuple
 
-from autoconf import conf
 import autofit as af
 import autogalaxy as ag
 
@@ -38,7 +33,7 @@ class AnalysisImaging(AnalysisDataset):
 
         This function:
 
-        - Checks that the hyper-dataset is consistent with previous hyper-datasets if the model-fit is being
+        - Checks that the adapt-dataset is consistent with previous adapt-datasets if the model-fit is being
           resumed from a previous run.
 
         - Checks the model and raises exceptions if certain critieria are not met.
@@ -58,23 +53,6 @@ class AnalysisImaging(AnalysisDataset):
 
         if not paths.is_complete:
 
-            if not os.environ.get("PYAUTOFIT_TEST_MODE") == "1":
-
-                visualizer = VisualizerImaging(visualize_path=paths.image_path)
-
-                visualizer.visualize_imaging(imaging=self.imaging)
-
-                if self.positions_likelihood is not None:
-                    visualizer.visualize_image_with_positions(
-                        image=self.imaging.image,
-                        positions=self.positions_likelihood.positions,
-                    )
-
-                visualizer.visualize_hyper_images(
-                    hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
-                    hyper_model_image=self.hyper_model_image,
-                )
-
             self.set_preloads(paths=paths, model=model)
 
         return self
@@ -88,7 +66,7 @@ class AnalysisImaging(AnalysisDataset):
 
         For this analysis class, this function performs the following steps:
 
-        1) If the analysis has a hyper dataset, associated the model galaxy images of this dataset to the galaxies in
+        1) If the analysis has a adapt dataset, associated the model galaxy images of this dataset to the galaxies in
            the model instance.
 
         2) Extract attributes which model aspects of the data reductions, like the scaling the background sky
@@ -148,9 +126,8 @@ class AnalysisImaging(AnalysisDataset):
     def fit_imaging_via_instance_from(
         self,
         instance: af.ModelInstance,
-        use_hyper_scaling: bool = True,
         preload_overwrite: Optional[Preloads] = None,
-        profiling_dict: Optional[Dict] = None,
+        run_time_dict: Optional[Dict] = None,
     ) -> FitImaging:
         """
         Given a model instance create a `FitImaging` object.
@@ -163,15 +140,12 @@ class AnalysisImaging(AnalysisDataset):
         instance
             An instance of the model that is being fitted to the data by this analysis (whose parameters have been set
             via a non-linear search).
-        use_hyper_scaling
-            If false, the scaling of the background sky and noise are not performed irrespective of the model components
-            themselves.
         preload_overwrite
             If a `Preload` object is input this is used instead of the preloads stored as an attribute in the analysis.
         check_positions
             Whether the multiple image positions of the lensed source should be checked, i.e. whether they trace
             within the position threshold of one another in the source plane.
-        profiling_dict
+        run_time_dict
             A dictionary which times functions called to fit the model to data, for profiling.
 
         Returns
@@ -179,34 +153,22 @@ class AnalysisImaging(AnalysisDataset):
         FitImaging
             The fit of the plane to the imaging dataset, which includes the log likelihood.
         """
-        self.instance_with_associated_hyper_images_from(instance=instance)
+        self.instance_with_associated_adapt_images_from(instance=instance)
         tracer = self.tracer_via_instance_from(
-            instance=instance, profiling_dict=profiling_dict
-        )
-
-        hyper_image_sky = self.hyper_image_sky_via_instance_from(instance=instance)
-
-        hyper_background_noise = self.hyper_background_noise_via_instance_from(
-            instance=instance
+            instance=instance, run_time_dict=run_time_dict
         )
 
         return self.fit_imaging_via_tracer_from(
             tracer=tracer,
-            hyper_image_sky=hyper_image_sky,
-            hyper_background_noise=hyper_background_noise,
-            use_hyper_scaling=use_hyper_scaling,
             preload_overwrite=preload_overwrite,
-            profiling_dict=profiling_dict,
+            run_time_dict=run_time_dict,
         )
 
     def fit_imaging_via_tracer_from(
         self,
         tracer: Tracer,
-        hyper_image_sky: Optional[ag.hyper_data.HyperImageSky],
-        hyper_background_noise: Optional[ag.hyper_data.HyperBackgroundNoise],
-        use_hyper_scaling: bool = True,
         preload_overwrite: Optional[Preloads] = None,
-        profiling_dict: Optional[Dict] = None,
+        run_time_dict: Optional[Dict] = None,
     ) -> FitImaging:
         """
         Given a `Tracer`, which the analysis constructs from a model instance, create a `FitImaging` object.
@@ -218,16 +180,9 @@ class AnalysisImaging(AnalysisDataset):
         ----------
         tracer
             The tracer of galaxies whose ray-traced model images are used to fit the imaging data.
-        hyper_image_sky
-            A model component which scales the background sky level of the data before computing the log likelihood.
-        hyper_background_noise
-            A model component which scales the background noise level of the data before computing the log likelihood.
-        use_hyper_scaling
-            If false, the scaling of the background sky and noise are not performed irrespective of the model components
-            themselves.
         preload_overwrite
             If a `Preload` object is input this is used instead of the preloads stored as an attribute in the analysis.
-        profiling_dict
+        run_time_dict
             A dictionary which times functions called to fit the model to data, for profiling.
 
         Returns
@@ -235,102 +190,21 @@ class AnalysisImaging(AnalysisDataset):
         FitImaging
             The fit of the plane to the imaging dataset, which includes the log likelihood.
         """
-        preloads = self.preloads if preload_overwrite is None else preload_overwrite
+        preloads = preload_overwrite or self.preloads
 
         return FitImaging(
             dataset=self.dataset,
             tracer=tracer,
-            hyper_image_sky=hyper_image_sky,
-            hyper_background_noise=hyper_background_noise,
-            use_hyper_scaling=use_hyper_scaling,
             settings_pixelization=self.settings_pixelization,
             settings_inversion=self.settings_inversion,
             preloads=preloads,
-            profiling_dict=profiling_dict,
+            run_time_dict=run_time_dict,
         )
 
     @property
     def fit_func(self):
         return self.fit_imaging_via_instance_from
 
-    def profile_log_likelihood_function(
-        self, instance: af.ModelInstance, paths: Optional[af.DirectoryPaths] = None
-    ):
-        """
-        This function is optionally called throughout a model-fit to profile the log likelihood function.
-
-        All function calls inside the `log_likelihood_function` that are decorated with the `profile_func` are timed
-        with their times stored in a dictionary called the `profiling_dict`.
-
-        An `info_dict` is also created which stores information no aspects of the model and dataset that dictate
-        run times, so the profiled times can be interpreted with this context.
-
-        The results of this profiling are then output to hard-disk in the `preloads` folder of the model-fit results,
-        which they can be inspected to ensure run-times are as expected.
-
-        Parameters
-        ----------
-        instance
-            An instance of the model that is being fitted to the data by this analysis (whose parameters have been set
-            via a non-linear search).
-        paths
-            The PyAutoFit paths object which manages all paths, e.g. where the non-linear search outputs are stored,
-            visualization and the pickled objects used by the aggregator output by this function.
-        """
-        profiling_dict = {}
-        info_dict = {}
-
-        repeats = conf.instance["general"]["profiling"]["repeats"]
-        info_dict["repeats"] = repeats
-
-        start = time.time()
-
-        for i in range(repeats):
-
-            try:
-                fit = self.fit_imaging_via_instance_from(instance=instance)
-            except exc.RayTracingException:
-                return
-
-            fit.figure_of_merit
-
-        fit_time = (time.time() - start) / repeats
-
-        info_dict["fit_time"] = fit_time
-
-        fit = self.fit_imaging_via_instance_from(
-            instance=instance, profiling_dict=profiling_dict
-        )
-        fit.figure_of_merit
-
-        info_dict["image_pixels"] = self.imaging.grid.sub_shape_slim
-        info_dict["sub_size_light_profiles"] = self.imaging.grid.sub_size
-        info_dict["sub_size_pixelization"] = self.imaging.grid_pixelization.sub_size
-        info_dict["psf_shape_2d"] = self.imaging.psf.shape_native
-
-        if fit.inversion is not None:
-            info_dict["source_pixels"] = len(fit.inversion.reconstruction)
-
-        if hasattr(fit.inversion, "w_tilde"):
-            info_dict[
-                "w_tilde_curvature_preload_size"
-            ] = fit.inversion.w_tilde.curvature_preload.shape[0]
-
-        if paths is not None:
-
-            try:
-                os.makedirs(paths.profile_path)
-            except FileExistsError:
-                pass
-
-            with open(path.join(paths.profile_path, "profiling_dict.json"), "w+") as f:
-                json.dump(fit.profiling_dict, f, indent=4)
-
-            with open(path.join(paths.profile_path, "info_dict.json"), "w+") as f:
-                json.dump(info_dict, f, indent=4)
-
-        return profiling_dict
-
     def stochastic_log_likelihoods_via_instance_from(self, instance: af.ModelInstance):
         """
         Certain `Inversion`'s have stochasticity in their log likelihood estimate.
@@ -356,7 +230,7 @@ class AnalysisImaging(AnalysisDataset):
             A log likelihood cap which is applied in a stochastic model-fit to give improved error and posterior
             estimates.
         """
-        instance = self.instance_with_associated_hyper_images_from(instance=instance)
+        instance = self.instance_with_associated_adapt_images_from(instance=instance)
         tracer = self.tracer_via_instance_from(instance=instance)
 
         if not tracer.has(cls=ag.Pixelization):
@@ -367,12 +241,6 @@ class AnalysisImaging(AnalysisDataset):
         ):
             return
 
-        hyper_image_sky = self.hyper_image_sky_via_instance_from(instance=instance)
-
-        hyper_background_noise = self.hyper_background_noise_via_instance_from(
-            instance=instance
-        )
-
         settings_pixelization = (
             self.settings_pixelization.settings_with_is_stochastic_true()
         )
@@ -386,8 +254,6 @@ class AnalysisImaging(AnalysisDataset):
                 log_evidence = FitImaging(
                     dataset=self.dataset,
                     tracer=tracer,
-                    hyper_image_sky=hyper_image_sky,
-                    hyper_background_noise=hyper_background_noise,
                     settings_pixelization=settings_pixelization,
                     settings_inversion=self.settings_inversion,
                     preloads=self.preloads,
@@ -406,6 +272,37 @@ class AnalysisImaging(AnalysisDataset):
 
         return log_evidences
 
+    def visualize_before_fit(self, paths: af.DirectoryPaths, model: af.Collection):
+        """
+        PyAutoFit calls this function immediately before the non-linear search begins.
+
+        It visualizes objects which do not change throughout the model fit like the dataset.
+
+        Parameters
+        ----------
+        paths
+            The PyAutoFit paths object which manages all paths, e.g. where the non-linear search outputs are stored,
+            visualization and the pickled objects used by the aggregator output by this function.
+        model
+            The PyAutoFit model object, which includes model components representing the galaxies that are fitted to
+            the imaging data.
+        """
+
+        visualizer = VisualizerImaging(visualize_path=paths.image_path)
+
+        visualizer.visualize_imaging(dataset=self.dataset)
+
+        if self.positions_likelihood is not None:
+            visualizer.visualize_image_with_positions(
+                image=self.dataset.data,
+                positions=self.positions_likelihood.positions,
+            )
+
+        visualizer.visualize_adapt_images(
+            adapt_galaxy_image_path_dict=self.adapt_galaxy_image_path_dict,
+            adapt_model_image=self.adapt_model_image,
+        )
+
     def visualize(
         self,
         paths: af.DirectoryPaths,
@@ -424,12 +321,9 @@ class AnalysisImaging(AnalysisDataset):
         - Images of the best-fit `FitImaging`, including the model-image, residuals and chi-squared of its fit to
           the imaging data.
 
-        - The hyper-images of the model-fit showing how the hyper galaxies are used to represent different galaxies in
+        - The adapt-images of the model-fit showing how the galaxies are used to represent different galaxies in
           the dataset.
 
-        - If hyper features are used to scale the noise or background sky, a `FitImaging` with these features turned
-          off may be output, to indicate how much these features are altering the dataset.
-
         The images output by this function are customized using the file `config/visualize/plots.ini`.
 
         Parameters
@@ -445,10 +339,7 @@ class AnalysisImaging(AnalysisDataset):
             which may change which images are output.
         """
 
-        if os.environ.get("PYAUTOFIT_TEST_MODE") == "1":
-            return
-
-        instance = self.instance_with_associated_hyper_images_from(instance=instance)
+        instance = self.instance_with_associated_adapt_images_from(instance=instance)
 
         fit = self.fit_imaging_via_instance_from(instance=instance)
 
@@ -479,28 +370,13 @@ class AnalysisImaging(AnalysisDataset):
             galaxies=tracer.galaxies, grid=fit.grid, during_analysis=during_analysis
         )
         if fit.inversion is not None:
-            visualizer.visualize_inversion(
-                inversion=fit.inversion, during_analysis=during_analysis
-            )
+            if fit.inversion.has(cls=ag.AbstractMapper):
+                visualizer.visualize_inversion(
+                    inversion=fit.inversion, during_analysis=during_analysis
+                )
 
         visualizer.visualize_contribution_maps(tracer=fit.tracer)
 
-        if visualizer.plot_fit_no_hyper:
-            fit = self.fit_imaging_via_tracer_from(
-                tracer=fit.tracer,
-                hyper_image_sky=None,
-                hyper_background_noise=None,
-                use_hyper_scaling=False,
-                preload_overwrite=Preloads(use_w_tilde=False),
-            )
-
-            try:
-                visualizer.visualize_fit_imaging(
-                    fit=fit, during_analysis=during_analysis, subfolders="fit_no_hyper"
-                )
-            except exc.InversionException:
-                pass
-
     def make_result(
         self,
         samples: af.SamplesPDF,
@@ -521,7 +397,7 @@ class AnalysisImaging(AnalysisDataset):
         - The non-linear search used to perform the model fit.
 
         The `ResultImaging` object contains a number of methods which use the above objects to create the max
-        log likelihood `Tracer`, `FitImaging`, hyper-galaxy images,etc.
+        log likelihood `Tracer`, `FitImaging`, adapt-galaxy images,etc.
 
         Parameters
         ----------
@@ -542,7 +418,7 @@ class AnalysisImaging(AnalysisDataset):
     def save_attributes_for_aggregator(self, paths: af.DirectoryPaths):
         """
         Before the non-linear search begins, this routine saves attributes of the `Analysis` object to the `pickles`
-        folder such that they can be load after the analysis using PyAutoFit's database and aggregator tools.
+        folder such that they can be loaded after the analysis using PyAutoFit's database and aggregator tools.
 
         For this analysis, it uses the `AnalysisDataset` object's method to output the following:
 
@@ -552,7 +428,7 @@ class AnalysisImaging(AnalysisDataset):
         - The settings associated with the inversion.
         - The settings associated with the pixelization.
         - The Cosmology.
-        - The hyper dataset's model image and galaxy images, if used.
+        - The adapt dataset's model image and galaxy images, if used.
 
         This function also outputs attributes specific to an imaging dataset:
 
@@ -579,3 +455,42 @@ class AnalysisImaging(AnalysisDataset):
         paths.save_object("psf", self.dataset.psf)
         paths.save_object("mask", self.dataset.mask)
         paths.save_object("positions_likelihood", self.positions_likelihood)
+
+    def profile_log_likelihood_function(
+        self, instance: af.ModelInstance, paths: Optional[af.DirectoryPaths] = None
+    ) -> Tuple[Dict, Dict]:
+        """
+        This function is optionally called throughout a model-fit to profile the log likelihood function.
+
+        All function calls inside the `log_likelihood_function` that are decorated with the `profile_func` are timed
+        with their times stored in a dictionary called the `run_time_dict`.
+
+        An `info_dict` is also created which stores information on aspects of the model and dataset that dictate
+        run times, so the profiled times can be interpreted with this context.
+
+        The results of this profiling are then output to hard-disk in the `preloads` folder of the model-fit results,
+        which they can be inspected to ensure run-times are as expected.
+
+        Parameters
+        ----------
+        instance
+            An instance of the model that is being fitted to the data by this analysis (whose parameters have been set
+            via a non-linear search).
+        paths
+            The PyAutoFit paths object which manages all paths, e.g. where the non-linear search outputs are stored,
+            visualization and the pickled objects used by the aggregator output by this function.
+
+        Returns
+        -------
+        Two dictionaries, the profiling dictionary and info dictionary, which contain the profiling times of the
+        `log_likelihood_function` and information on the model and dataset used to perform the profiling.
+        """
+        run_time_dict, info_dict = super().profile_log_likelihood_function(
+            instance=instance,
+        )
+
+        info_dict["psf_shape_2d"] = self.dataset.psf.shape_native
+
+        self.output_profiling_info(paths=paths, run_time_dict=run_time_dict, info_dict=info_dict)
+
+        return run_time_dict, info_dict
\ No newline at end of file
