@@ -9,7 +9,7 @@ from autolens.analysis.visualizer import plot_setting
 
 class VisualizerImaging(Visualizer):
     def visualize_fit_imaging(
-        self, fit: FitImaging, during_analysis: bool, subfolders: str = "fit_imaging"
+        self, fit: FitImaging, during_analysis: bool, subfolders: str = "fit_dataset"
     ):
         """
         Visualizes a `FitImaging` object, which fits an imaging dataset.
@@ -40,12 +40,12 @@ class VisualizerImaging(Visualizer):
 
         mat_plot_2d = self.mat_plot_2d_from(subfolders=subfolders)
 
-        fit_imaging_plotter = FitImagingPlotter(
+        fit_plotter = FitImagingPlotter(
             fit=fit, mat_plot_2d=mat_plot_2d, include_2d=self.include_2d
         )
 
-        fit_imaging_plotter.figures_2d(
-            image=should_plot("data"),
+        fit_plotter.figures_2d(
+            data=should_plot("data"),
             noise_map=should_plot("noise_map"),
             signal_to_noise_map=should_plot("signal_to_noise_map"),
             model_image=should_plot("model_data"),
@@ -54,56 +54,62 @@ class VisualizerImaging(Visualizer):
             normalized_residual_map=should_plot("normalized_residual_map"),
         )
 
-        fit_imaging_plotter.figures_2d_of_planes(
+        fit_plotter.figures_2d_of_planes(
             subtracted_image=should_plot("subtracted_images_of_planes"),
             model_image=should_plot("model_images_of_planes"),
             plane_image=should_plot("plane_images_of_planes"),
         )
 
         if should_plot("subplot_fit"):
-            fit_imaging_plotter.subplot_fit_imaging()
+            fit_plotter.subplot_fit()
 
-        if should_plot("subplots_of_planes_fits"):
-            fit_imaging_plotter.subplot_of_planes()
+        if should_plot("subplot_of_planes"):
+            fit_plotter.subplot_of_planes()
 
-        if not during_analysis:
+        if not during_analysis and should_plot("all_at_end_png"):
 
-            if should_plot("all_at_end_png"):
+            mat_plot_2d = self.mat_plot_2d_from(
+                subfolders=path.join("fit_dataset", "end"),
+            )
 
-                fit_imaging_plotter.figures_2d(
-                    image=True,
-                    noise_map=True,
-                    signal_to_noise_map=True,
-                    model_image=True,
-                    residual_map=True,
-                    normalized_residual_map=True,
-                    chi_squared_map=True,
-                )
+            fit_plotter = FitImagingPlotter(
+                fit=fit, mat_plot_2d=mat_plot_2d, include_2d=self.include_2d
+            )
 
-                fit_imaging_plotter.figures_2d_of_planes(
-                    subtracted_image=True, model_image=True, plane_image=True
-                )
+            fit_plotter.figures_2d(
+                data=True,
+                noise_map=True,
+                signal_to_noise_map=True,
+                model_image=True,
+                residual_map=True,
+                normalized_residual_map=True,
+                chi_squared_map=True,
+            )
 
-            if should_plot("all_at_end_fits"):
+            fit_plotter.figures_2d_of_planes(
+                subtracted_image=True, model_image=True, plane_image=True
+            )
 
-                mat_plot_2d = self.mat_plot_2d_from(
-                    subfolders=path.join("fit_imaging", "fits"), format="fits"
-                )
+        if not during_analysis and should_plot("all_at_end_fits"):
 
-                fit_imaging_plotter = FitImagingPlotter(
-                    fit=fit, mat_plot_2d=mat_plot_2d, include_2d=self.include_2d
-                )
+            mat_plot_2d = self.mat_plot_2d_from(
+                subfolders=path.join("fit_dataset", "fits"), format="fits"
+            )
 
-                fit_imaging_plotter.figures_2d(
-                    image=True,
-                    noise_map=True,
-                    signal_to_noise_map=True,
-                    model_image=True,
-                    residual_map=True,
-                    normalized_residual_map=True,
-                    chi_squared_map=True,
-                )
+            fit_plotter = FitImagingPlotter(
+                fit=fit, mat_plot_2d=mat_plot_2d, include_2d=self.include_2d
+            )
 
-                fit_imaging_plotter.figures_2d_of_planes(
-                    subtracted_image=True, model_image=True
-                )
+            fit_plotter.figures_2d(
+                data=True,
+                noise_map=True,
+                signal_to_noise_map=True,
+                model_image=True,
+                residual_map=True,
+                normalized_residual_map=True,
+                chi_squared_map=True,
+            )
+
+            fit_plotter.figures_2d_of_planes(
+                subtracted_image=True, model_image=True, plane_image=True, interpolate_to_uniform=True
+            )
