@@ -64,10 +64,6 @@ class FitImagingPlotter(Plotter):
 
         self.residuals_symmetric_cmap = residuals_symmetric_cmap
 
-        # self.figures_2d = self._fit_imaging_meta_plotter.figures_2d
-        # self.subplot = self._fit_imaging_meta_plotter.subplot
-        # self.subplot_fit_imaging = self._fit_imaging_meta_plotter.subplot_fit_imaging
-
     def get_visuals_2d(self) -> aplt.Visuals2D:
         return self.get_2d.via_fit_imaging_from(fit=self.fit)
 
@@ -111,6 +107,7 @@ class FitImagingPlotter(Plotter):
             ),
             include_2d=self.include_2d,
         )
+        inversion_plotter.visuals_2d.mask = None
         inversion_plotter.visuals_2d.border = None
         return inversion_plotter
 
@@ -139,6 +136,9 @@ class FitImagingPlotter(Plotter):
         subtracted_image: bool = False,
         model_image: bool = False,
         plane_image: bool = False,
+        use_source_vmax: bool = False,
+        zoom_to_brightest: bool = True,
+        interpolate_to_uniform: bool = False,
     ):
         """
         Plots images representing each individual `Plane` in the fit's `Tracer` in 2D, which are computed via the
@@ -165,34 +165,34 @@ class FitImagingPlotter(Plotter):
             Whether to make a 2D plot (via `imshow`) of the image of a plane in its source-plane (e.g. unlensed).
             Depending on how the fit is performed, this could either be an image of light profiles of the reconstruction
             of an `Inversion`.
+        use_source_vmax
+            If `True`, the maximum value of the lensed source (e.g. in the image-plane) is used to set the `vmax` of
+            certain plots (e.g. the `data`) in order to ensure the lensed source is visible compared to the lens.
+        zoom_to_brightest
+            For images not in the image-plane (e.g. the `plane_image`), whether to automatically zoom the plot to
+            the brightest regions of the galaxies being plotted as opposed to the full extent of the grid.
+        interpolate_to_uniform
+            If `True`, the mapper's reconstruction is interpolated to a uniform grid before plotting, for example
+            meaning that an irregular Delaunay grid can be plotted as a uniform grid.
         """
 
         visuals_2d = self.get_visuals_2d()
 
         visuals_2d_no_critical_caustic = self.get_visuals_2d()
-        visuals_2d_no_critical_caustic.critical_curves = None
-        visuals_2d_no_critical_caustic.caustics = None
+        visuals_2d_no_critical_caustic.tangential_critical_curves = None
+        visuals_2d_no_critical_caustic.radial_critical_curves = None
+        visuals_2d_no_critical_caustic.tangential_caustics = None
+        visuals_2d_no_critical_caustic.radial_caustics = None
 
         plane_indexes = self.plane_indexes_from(plane_index=plane_index)
 
+        if use_source_vmax:
+            self.mat_plot_2d.cmap.kwargs["vmax"] = np.max(self.fit.model_images_of_planes_list[-1])
+
         for plane_index in plane_indexes:
 
             if subtracted_image:
 
-                if "vmin" in self.mat_plot_2d.cmap.kwargs:
-                    vmin_stored = True
-                else:
-                    self.mat_plot_2d.cmap.kwargs["vmin"] = 0.0
-                    vmin_stored = False
-
-                if "vmax" in self.mat_plot_2d.cmap.kwargs:
-                    vmax_stored = True
-                else:
-                    self.mat_plot_2d.cmap.kwargs["vmax"] = np.max(
-                        self.fit.model_images_of_planes_list[plane_index]
-                    )
-                    vmax_stored = False
-
                 self.mat_plot_2d.plot_array(
                     array=self.fit.subtracted_images_of_planes_list[plane_index],
                     visuals_2d=visuals_2d_no_critical_caustic,
@@ -202,12 +202,6 @@ class FitImagingPlotter(Plotter):
                     ),
                 )
 
-                if not vmin_stored:
-                    self.mat_plot_2d.cmap.kwargs.pop("vmin")
-
-                if not vmax_stored:
-                    self.mat_plot_2d.cmap.kwargs.pop("vmax")
-
             if model_image:
 
                 if self.tracer.planes[plane_index].has(cls=aa.Pixelization):
@@ -234,7 +228,9 @@ class FitImagingPlotter(Plotter):
                 if not self.tracer.planes[plane_index].has(cls=aa.Pixelization):
 
                     self.tracer_plotter.figures_2d_of_planes(
-                        plane_image=True, plane_index=plane_index
+                        plane_image=True,
+                        plane_index=plane_index,
+                        zoom_to_brightest=zoom_to_brightest
                     )
 
                 elif self.tracer.planes[plane_index].has(cls=aa.Pixelization):
@@ -242,10 +238,17 @@ class FitImagingPlotter(Plotter):
                     inversion_plotter = self.inversion_plotter_of_plane(
                         plane_index=plane_index
                     )
+
                     inversion_plotter.figures_2d_of_pixelization(
-                        pixelization_index=0, reconstruction=True
+                        pixelization_index=0,
+                        reconstruction=True,
+                        zoom_to_brightest=zoom_to_brightest,
+                        interpolate_to_uniform=interpolate_to_uniform
                     )
 
+        if use_source_vmax:
+            self.mat_plot_2d.cmap.kwargs.pop("vmax")
+
     def subplot_of_planes(self, plane_index: Optional[int] = None):
         """
         Plots images representing each individual `Plane` in the plotter's `Tracer` in 2D on a subplot, which are
@@ -269,7 +272,8 @@ class FitImagingPlotter(Plotter):
 
             self.open_subplot_figure(number_subplots=4)
 
-            self.figures_2d(image=True)
+            self.figures_2d(data=True)
+
             self.figures_2d_of_planes(subtracted_image=True, plane_index=plane_index)
             self.figures_2d_of_planes(model_image=True, plane_index=plane_index)
             self.figures_2d_of_planes(plane_image=True, plane_index=plane_index)
@@ -281,14 +285,14 @@ class FitImagingPlotter(Plotter):
 
     def subplot(
         self,
-        image: bool = False,
+        data: bool = False,
         noise_map: bool = False,
         signal_to_noise_map: bool = False,
-        model_image: bool = False,
+        model_data: bool = False,
         residual_map: bool = False,
         normalized_residual_map: bool = False,
         chi_squared_map: bool = False,
-        auto_filename: str = "subplot_fit_imaging",
+        auto_filename: str = "subplot_fit",
     ):
         """
         Plots the individual attributes of the plotter's `FitImaging` object in 2D on a subplot.
@@ -298,58 +302,117 @@ class FitImagingPlotter(Plotter):
 
         Parameters
         ----------
-        image
-            Whether or not to include a 2D plot (via `imshow`) of the image data.
+        data
+            Whether to include a 2D plot (via `imshow`) of the image data.
         noise_map
-            Whether or not to include a 2D plot (via `imshow`) of the noise map.
+            Whether to include a 2D plot (via `imshow`) of the noise map.
         psf
-            Whether or not to include a 2D plot (via `imshow`) of the psf.
+            Whether to include a 2D plot (via `imshow`) of the psf.
         signal_to_noise_map
-            Whether or not to include a 2D plot (via `imshow`) of the signal-to-noise map.
-        model_image
-            Whether or not to include a 2D plot (via `imshow`) of the model image.
+            Whether to include a 2D plot (via `imshow`) of the signal-to-noise map.
+        model_data
+            Whether to include a 2D plot (via `imshow`) of the model image.
         residual_map
-            Whether or not to include a 2D plot (via `imshow`) of the residual map.
+            Whether to include a 2D plot (via `imshow`) of the residual map.
         normalized_residual_map
-            Whether or not to include a 2D plot (via `imshow`) of the normalized residual map.
+            Whether to include a 2D plot (via `imshow`) of the normalized residual map.
         chi_squared_map
-            Whether or not to include a 2D plot (via `imshow`) of the chi-squared map.
+            Whether to include a 2D plot (via `imshow`) of the chi-squared map.
         auto_filename
             The default filename of the output subplot if written to hard-disk.
         """
         self._subplot_custom_plot(
-            image=image,
+            data=data,
             noise_map=noise_map,
             signal_to_noise_map=signal_to_noise_map,
-            model_image=model_image,
+            model_image=model_data,
             residual_map=residual_map,
             normalized_residual_map=normalized_residual_map,
             chi_squared_map=chi_squared_map,
             auto_labels=AutoLabels(filename=auto_filename),
         )
 
-    def subplot_fit_imaging(self):
+    def subplot_fit(self):
         """
         Standard subplot of the attributes of the plotter's `FitImaging` object.
         """
-        return self.subplot(
-            image=True,
-            signal_to_noise_map=True,
-            model_image=True,
-            residual_map=True,
-            normalized_residual_map=True,
-            chi_squared_map=True,
+
+        self.open_subplot_figure(number_subplots=12)
+
+        self.figures_2d(data=True)
+
+        self.set_title(label="Data (Source Scale)")
+        self.figures_2d(data=True, use_source_vmax=True)
+        self.set_title(label=None)
+
+        self.figures_2d(signal_to_noise_map=True)
+        self.figures_2d(model_image=True)
+
+        self.set_title(label="Lens Light Model Image")
+        self.figures_2d_of_planes(plane_index=0, model_image=True)
+
+        # If the lens light is not included the subplot index does not increase, so we must manually set it to 4
+        self.mat_plot_2d.subplot_index = 6
+
+        final_plane_index = len(self.fit.tracer.planes) - 1
+
+        self.mat_plot_2d.cmap.kwargs["vmin"] = 0.0
+
+        self.set_title(label="Lens Light Subtracted Image")
+        self.figures_2d_of_planes(plane_index=final_plane_index, subtracted_image=True, use_source_vmax=True)
+
+        self.set_title(label="Source Model Image (Image Plane)")
+        self.figures_2d_of_planes(plane_index=final_plane_index, model_image=True, use_source_vmax=True)
+
+        self.mat_plot_2d.cmap.kwargs.pop("vmin")
+
+        self.set_title(label="Source Plane (Zoomed)")
+        self.figures_2d_of_planes(plane_index=final_plane_index, plane_image=True, use_source_vmax=True)
+
+
+        self.set_title(label=None)
+
+        self.mat_plot_2d.subplot_index = 9
+
+        self.figures_2d(normalized_residual_map=True)
+
+        self.mat_plot_2d.cmap.kwargs["vmin"] = -1.0
+        self.mat_plot_2d.cmap.kwargs["vmax"] = 1.0
+
+        self.set_title(label="Normalized Residual Map (1 sigma)")
+        self.figures_2d(normalized_residual_map=True)
+        self.set_title(label=None)
+
+        self.mat_plot_2d.cmap.kwargs.pop("vmin")
+        self.mat_plot_2d.cmap.kwargs.pop("vmax")
+
+        self.figures_2d(chi_squared_map=True)
+
+        self.set_title(label="Source Plane (No Zoom)")
+        self.figures_2d_of_planes(
+            plane_index=final_plane_index,
+            plane_image=True,
+            zoom_to_brightest=False,
+            use_source_vmax=True
         )
 
+        self.set_title(label=None)
+
+        self.mat_plot_2d.output.subplot_to_figure(
+            auto_filename="subplot_fit"
+        )
+        self.close_subplot_figure()
+
     def figures_2d(
         self,
-        image: bool = False,
+        data: bool = False,
         noise_map: bool = False,
         signal_to_noise_map: bool = False,
         model_image: bool = False,
         residual_map: bool = False,
         normalized_residual_map: bool = False,
         chi_squared_map: bool = False,
+        use_source_vmax : bool = False,
         suffix: str = "",
     ):
         """
@@ -360,7 +423,7 @@ class FitImagingPlotter(Plotter):
 
         Parameters
         ----------
-        image
+        data
             Whether to make a 2D plot (via `imshow`) of the image data.
         noise_map
             Whether to make a 2D plot (via `imshow`) of the noise map.
@@ -374,25 +437,36 @@ class FitImagingPlotter(Plotter):
             Whether to make a 2D plot (via `imshow`) of the normalized residual map.
         chi_squared_map
             Whether to make a 2D plot (via `imshow`) of the chi-squared map.
+        use_source_vmax
+            If `True`, the maximum value of the lensed source (e.g. in the image-plane) is used to set the `vmax` of
+            certain plots (e.g. the `data`) in order to ensure the lensed source is visible compared to the lens.
         """
 
         visuals_2d = self.get_visuals_2d()
 
         visuals_2d_no_critical_caustic = self.get_visuals_2d()
-        visuals_2d_no_critical_caustic.critical_curves = None
-        visuals_2d_no_critical_caustic.caustics = None
+        visuals_2d_no_critical_caustic.tangential_critical_curves = None
+        visuals_2d_no_critical_caustic.radial_critical_curves = None
+        visuals_2d_no_critical_caustic.tangential_caustics = None
+        visuals_2d_no_critical_caustic.radial_caustics = None
         visuals_2d_no_critical_caustic.origin = None
         visuals_2d_no_critical_caustic.light_profile_centres = None
         visuals_2d_no_critical_caustic.mass_profile_centres = None
 
-        if image:
+        if data:
+
+            if use_source_vmax:
+                self.mat_plot_2d.cmap.kwargs["vmax"] = np.max(self.fit.model_images_of_planes_list[-1])
 
             self.mat_plot_2d.plot_array(
                 array=self.fit.data,
                 visuals_2d=visuals_2d_no_critical_caustic,
-                auto_labels=AutoLabels(title="Image", filename=f"image_2d{suffix}"),
+                auto_labels=AutoLabels(title="Data", filename=f"data{suffix}"),
             )
 
+            if use_source_vmax:
+                self.mat_plot_2d.cmap.kwargs.pop("vmax")
+
         if noise_map:
 
             self.mat_plot_2d.plot_array(
@@ -409,12 +483,15 @@ class FitImagingPlotter(Plotter):
                 array=self.fit.signal_to_noise_map,
                 visuals_2d=visuals_2d_no_critical_caustic,
                 auto_labels=AutoLabels(
-                    title="Signal-To-Noise Map", filename=f"signal_to_noise_map{suffix}"
+                    title="Signal-To-Noise Map", cb_unit=" S/N", filename=f"signal_to_noise_map{suffix}"
                 ),
             )
 
         if model_image:
 
+            if use_source_vmax:
+                self.mat_plot_2d.cmap.kwargs["vmax"] = np.max(self.fit.model_images_of_planes_list[-1])
+
             self.mat_plot_2d.plot_array(
                 array=self.fit.model_data,
                 visuals_2d=visuals_2d,
@@ -423,6 +500,9 @@ class FitImagingPlotter(Plotter):
                 ),
             )
 
+            if use_source_vmax:
+                self.mat_plot_2d.cmap.kwargs.pop("vmax")
+
         cmap_original = self.mat_plot_2d.cmap
 
         if self.residuals_symmetric_cmap:
@@ -446,6 +526,7 @@ class FitImagingPlotter(Plotter):
                 visuals_2d=visuals_2d_no_critical_caustic,
                 auto_labels=AutoLabels(
                     title="Normalized Residual Map",
+                    cb_unit=r" $\sigma$",
                     filename=f"normalized_residual_map{suffix}",
                 ),
             )
@@ -458,6 +539,6 @@ class FitImagingPlotter(Plotter):
                 array=self.fit.chi_squared_map,
                 visuals_2d=visuals_2d_no_critical_caustic,
                 auto_labels=AutoLabels(
-                    title="Chi-Squared Map", filename=f"chi_squared_map{suffix}"
+                    title="Chi-Squared Map", cb_unit=r" $\chi^2$",  filename=f"chi_squared_map{suffix}"
                 ),
             )
\ No newline at end of file
