@@ -18,12 +18,10 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         self,
         dataset: aa.Interferometer,
         tracer: Tracer,
-        hyper_background_noise: ag.hyper_data.HyperBackgroundNoise = None,
-        use_hyper_scaling: bool = True,
         settings_pixelization: aa.SettingsPixelization = aa.SettingsPixelization(),
         settings_inversion: aa.SettingsInversion = aa.SettingsInversion(),
         preloads: Preloads = Preloads(),
-        profiling_dict: Optional[Dict] = None,
+        run_time_dict: Optional[Dict] = None,
     ):
         """
         Fits an interferometer dataset using a `Tracer` object.
@@ -56,11 +54,6 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
             The interforometer dataset which is fitted by the galaxies in the tracer.
         tracer
             The tracer of galaxies whose light profile images are used to fit the interferometer data.
-        hyper_background_noise
-            If included, adds a noise-scaling term to the background noise.
-        use_hyper_scaling
-            If set to False, the hyper scaling functions (e.g. the `hyper_background_noise`) are
-            omitted irrespective of their inputs.
         settings_pixelization
             Settings controlling how a pixelization is fitted for example if a border is used when creating the
             pixelization.
@@ -69,7 +62,7 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         preloads
             Contains preloaded calculations (e.g. linear algebra matrices) which can skip certain calculations in
             the fit.
-        profiling_dict
+        run_time_dict
             A dictionary which if passed to the fit records how long fucntion calls which have the `profile_func`
             decorator take to run.
         """
@@ -81,35 +74,18 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
 
         self.tracer = tracer
 
-        self.hyper_background_noise = hyper_background_noise
-        self.use_hyper_scaling = use_hyper_scaling
-
         self.settings_pixelization = settings_pixelization
         self.settings_inversion = settings_inversion
 
         self.preloads = preloads
 
-        self.profiling_dict = profiling_dict
+        self.run_time_dict = run_time_dict
 
-        super().__init__(dataset=dataset, profiling_dict=profiling_dict)
+        super().__init__(dataset=dataset, run_time_dict=run_time_dict)
         AbstractFitInversion.__init__(
             self=self, model_obj=tracer, settings_inversion=settings_inversion
         )
 
-    @property
-    def noise_map(self) -> aa.Visibilities:
-        """
-        Returns the interferometer's noise-map, which may have a hyper scaling performed which increase the noise in
-        regions of the data that are poorly fitted in order to avoid overfitting.
-        """
-        if self.use_hyper_scaling and self.hyper_background_noise is not None:
-
-            return self.hyper_background_noise.hyper_noise_map_complex_from(
-                noise_map=self.dataset.noise_map
-            )
-
-        return self.dataset.noise_map
-
     @property
     def profile_visibilities(self) -> aa.Visibilities:
         """
@@ -130,7 +106,6 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
 
     @property
     def tracer_to_inversion(self) -> TracerToInversion:
-
         return TracerToInversion(
             tracer=self.tracer,
             dataset=self.dataset,
@@ -167,14 +142,13 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         """
 
         if self.perform_inversion:
-
             return self.profile_visibilities + self.inversion.mapped_reconstructed_data
 
         return self.profile_visibilities
 
     @property
     def grid(self) -> aa.type.Grid2DLike:
-        return self.interferometer.grid
+        return self.dataset.grid
 
     @property
     def galaxy_model_image_dict(self) -> Dict[ag.Galaxy, np.ndarray]:
@@ -187,7 +161,7 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         - The images of all linear objects (e.g. linear light profiles / pixelizations), where the images are solved
           for first via the inversion.
 
-        For modeling, this dictionary is used to set up the `hyper_images` that adapt certain pixelizations to the
+        For modeling, this dictionary is used to set up the `adapt_images` that adapt certain pixelizations to the
         data being fitted.
         """
         galaxy_model_image_dict = self.tracer.galaxy_image_2d_dict_from(grid=self.grid)
@@ -209,12 +183,9 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
           space.
         - The visibilities of all linear objects (e.g. linear light profiles / pixelizations), where the visibilities
           are solved for first via the inversion.
-
-        For modeling, this dictionary is used to set up the `hyper_visibilities` that adapt certain pixelizations to the
-        data being fitted.
         """
         galaxy_model_visibilities_dict = self.tracer.galaxy_visibilities_dict_from(
-            grid=self.interferometer.grid, transformer=self.interferometer.transformer
+            grid=self.dataset.grid, transformer=self.dataset.transformer
         )
 
         galaxy_linear_obj_visibilities_dict = self.galaxy_linear_obj_data_dict_from(
@@ -286,10 +257,10 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         -------
         A new fit which has used new preloads input into this function but the same dataset, tracer and other settings.
         """
-        if self.profiling_dict is not None:
-            profiling_dict = {}
+        if self.run_time_dict is not None:
+            run_time_dict = {}
         else:
-            profiling_dict = None
+            run_time_dict = None
 
         if settings_inversion is None:
             settings_inversion = self.settings_inversion
@@ -297,10 +268,8 @@ class FitInterferometer(aa.FitInterferometer, AbstractFitInversion):
         return FitInterferometer(
             dataset=self.interferometer,
             tracer=self.tracer,
-            hyper_background_noise=self.hyper_background_noise,
-            use_hyper_scaling=self.use_hyper_scaling,
             settings_pixelization=self.settings_pixelization,
             settings_inversion=settings_inversion,
             preloads=preloads,
-            profiling_dict=profiling_dict,
+            run_time_dict=run_time_dict,
         )
