@@ -1,7 +1,6 @@
 import logging
 import numpy as np
-import os
-from typing import Optional, Union
+from typing import Dict, Optional, Tuple, Union
 
 import autofit as af
 import autoarray as aa
@@ -33,7 +32,7 @@ class AnalysisInterferometer(AnalysisDataset):
         positions_likelihood: Optional[
             Union[PositionsLHResample, PositionsLHPenalty]
         ] = None,
-        hyper_dataset_result=None,
+        adapt_result=None,
         cosmology: ag.cosmo.LensingCosmology = ag.cosmo.Planck15(),
         settings_pixelization: aa.SettingsPixelization = None,
         settings_inversion: aa.SettingsInversion = None,
@@ -52,7 +51,7 @@ class AnalysisInterferometer(AnalysisDataset):
         `Tracer`) to an interferometer dataset.
 
         This class stores the settings used to perform the model-fit for certain components of the model (e.g. a
-        pixelization or inversion), the Cosmology used for the analysis and hyper datasets used for certain model
+        pixelization or inversion), the Cosmology used for the analysis and adapt datasets used for certain model
         classes.
 
         Parameters
@@ -63,8 +62,8 @@ class AnalysisInterferometer(AnalysisDataset):
             An object which alters the likelihood function to include a term which accounts for whether
             image-pixel coordinates in arc-seconds corresponding to the multiple images of the lensed source galaxy
             trace close to one another in the source-plane.
-        hyper_dataset_result
-            The hyper-model image and hyper galaxies images of a previous result in a model-fitting pipeline, which are
+        adapt_result
+            Theadapt-model image and galaxies images of a previous result in a model-fitting pipeline, which are
             used by certain classes for adapting the analysis to the properties of the dataset.
         cosmology
             The Cosmology assumed for this analysis.
@@ -85,7 +84,7 @@ class AnalysisInterferometer(AnalysisDataset):
         super().__init__(
             dataset=dataset,
             positions_likelihood=positions_likelihood,
-            hyper_dataset_result=hyper_dataset_result,
+            adapt_result=adapt_result,
             cosmology=cosmology,
             settings_pixelization=settings_pixelization,
             settings_inversion=settings_inversion,
@@ -93,15 +92,6 @@ class AnalysisInterferometer(AnalysisDataset):
             raise_inversion_positions_likelihood_exception=raise_inversion_positions_likelihood_exception,
         )
 
-        if self.hyper_dataset_result is not None:
-
-            self.set_hyper_dataset(result=self.hyper_dataset_result)
-
-        else:
-
-            self.hyper_galaxy_visibilities_path_dict = None
-            self.hyper_model_visibilities = None
-
     @property
     def interferometer(self):
         return self.dataset
@@ -111,7 +101,7 @@ class AnalysisInterferometer(AnalysisDataset):
         PyAutoFit calls this function immediately before the non-linear search begins, therefore it can be used to
         perform tasks using the final model parameterization.
 
-        This function checks that the hyper-dataset is consistent with previous hyper-datasets if the model-fit is
+        This function checks that the adapt-dataset is consistent with previous adapt-datasets if the model-fit is
         being resumed from a previous run, and it visualizes objects which do not change throughout the model fit
         like the dataset.
 
@@ -127,24 +117,6 @@ class AnalysisInterferometer(AnalysisDataset):
         super().modify_before_fit(paths=paths, model=model)
 
         if not paths.is_complete:
-
-            if not os.environ.get("PYAUTOFIT_TEST_MODE") == "1":
-
-                visualizer = VisualizerInterferometer(visualize_path=paths.image_path)
-
-                visualizer.visualize_interferometer(interferometer=self.interferometer)
-
-                if self.positions_likelihood is not None:
-                    visualizer.visualize_image_with_positions(
-                        image=self.interferometer.dirty_image,
-                        positions=self.positions_likelihood.positions,
-                    )
-
-                visualizer.visualize_hyper_images(
-                    hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
-                    hyper_model_image=self.hyper_model_image,
-                )
-
             logger.info(
                 "PRELOADS - Setting up preloads, may take a few minutes for fits using an inversion."
             )
@@ -153,72 +125,6 @@ class AnalysisInterferometer(AnalysisDataset):
 
         return self
 
-    def set_hyper_dataset(self, result):
-        """
-        Using a the result of a previous model-fit, set the hyper-dataset for this analysis. This is used to adapt
-        aspects of the model (e.g. the pixelization, regularization scheme) to the properties of the dataset being
-        fitted.
-
-        This passes the hyper model image and hyper galaxy images of the previous fit. These represent where different
-        galaxies in the dataset are located and thus allows the fit to adapt different aspects of the model to
-        different galaxies in the data.
-
-        It also passes hyper visibilities, which are used to scale the noise of a visibility dataset.
-
-        Parameters
-        ----------
-        result
-            The result of a previous model-fit which contains the model image and model galaxy images of a fit to
-            the dataset, which set up the hyper dataset. These are used by certain classes for adapting the analysis
-            to the properties of the dataset.
-        """
-        super().set_hyper_dataset(result=result)
-
-        self.hyper_model_visibilities = result.hyper_model_visibilities
-        self.hyper_galaxy_visibilities_path_dict = (
-            result.hyper_galaxy_visibilities_path_dict
-        )
-
-    def instance_with_associated_hyper_visibilities_from(
-        self, instance: af.ModelInstance
-    ) -> af.ModelInstance:
-        """
-        Using the model visibilities that were set up as the hyper dataset, associate the galaxy images of that result
-        with the galaxies in this model fit.
-
-        Association is performed based on galaxy names, whereby if the name of a galaxy in this search matches the
-        full-path name of galaxies in the hyper dataset the galaxy image is passed.
-
-        If the galaxy collection has a different name then an association is not made.
-
-        For example, `galaxies.lens` will match with:
-            `galaxies.lens`
-        but not with:
-            `galaxies.source`
-
-        Parameters
-        ----------
-        instance
-            An instance of the model that is being fitted to the data by this analysis (whose parameters have been set
-            via a non-linear search), which has 0 or more galaxies in its tree.
-
-        Returns
-        -------
-        instance
-           The input instance with visibilities associated with galaxies where possible.
-        """
-        if self.hyper_galaxy_visibilities_path_dict is not None:
-            for galaxy_path, galaxy in instance.path_instance_tuples_for_class(
-                ag.Galaxy
-            ):
-                if galaxy_path in self.hyper_galaxy_visibilities_path_dict:
-                    galaxy.hyper_model_visibilities = self.hyper_model_visibilities
-                    galaxy.hyper_galaxy_visibilities = (
-                        self.hyper_galaxy_visibilities_path_dict[galaxy_path]
-                    )
-
-        return instance
-
     def log_likelihood_function(self, instance):
         """
         Given an instance of the model, where the model parameters are set via a non-linear search, fit the model
@@ -228,7 +134,7 @@ class AnalysisInterferometer(AnalysisDataset):
 
         For this analysis class, this function performs the following steps:
 
-        1) If the analysis has a hyper dataset, associated the model galaxy images of this dataset to the galaxies in
+        1) If the analysis has a adapt dataset, associated the model galaxy images of this dataset to the galaxies in
            the model instance.
 
         2) Extract attributes which model aspects of the data reductions, like the scaling the background sky
@@ -286,8 +192,7 @@ class AnalysisInterferometer(AnalysisDataset):
     def fit_interferometer_via_instance_from(
         self,
         instance: af.ModelInstance,
-        use_hyper_scaling: bool = True,
-        preload_overwrite: Optional[Preloads] = None,
+        run_time_dict: Optional[Dict] = None,
     ) -> FitInterferometer:
         """
         Given a model instance create a `FitInterferometer` object.
@@ -300,15 +205,12 @@ class AnalysisInterferometer(AnalysisDataset):
         instance
             An instance of the model that is being fitted to the data by this analysis (whose parameters have been set
             via a non-linear search).
-        use_hyper_scaling
-            If false, the scaling of the background sky and noise are not performed irrespective of the model components
-            themselves.
         preload_overwrite
             If a `Preload` object is input this is used instead of the preloads stored as an attribute in the analysis.
         check_positions
             Whether the multiple image positions of the lensed source should be checked, i.e. whether they trace
             within the position threshold of one another in the source plane.
-        profiling_dict
+        run_time_dict
             A dictionary which times functions called to fit the model to data, for profiling.
 
         Returns
@@ -316,25 +218,20 @@ class AnalysisInterferometer(AnalysisDataset):
         FitInterferometer
             The fit of the plane to the interferometer dataset, which includes the log likelihood.
         """
-        self.instance_with_associated_hyper_images_from(instance=instance)
-        tracer = self.tracer_via_instance_from(instance=instance)
-
-        hyper_background_noise = self.hyper_background_noise_via_instance_from(
-            instance=instance
+        self.instance_with_associated_adapt_images_from(instance=instance)
+        tracer = self.tracer_via_instance_from(
+            instance=instance, run_time_dict=run_time_dict
         )
 
         return self.fit_interferometer_via_tracer_from(
-            tracer=tracer,
-            hyper_background_noise=hyper_background_noise,
-            use_hyper_scaling=use_hyper_scaling,
+            tracer=tracer, run_time_dict=run_time_dict
         )
 
     def fit_interferometer_via_tracer_from(
         self,
         tracer: Tracer,
-        hyper_background_noise: Optional[ag.hyper_data.HyperBackgroundNoise],
-        use_hyper_scaling: bool = True,
         preload_overwrite: Optional[Preloads] = None,
+        run_time_dict: Optional[Dict] = None,
     ):
         """
         Given a `Tracer`, which the analysis constructs from a model instance, create a `FitInterferometer` object.
@@ -346,16 +243,9 @@ class AnalysisInterferometer(AnalysisDataset):
         ----------
         tracer
             The tracer of galaxies whose ray-traced model images are used to fit the imaging data.
-        hyper_image_sky
-            A model component which scales the background sky level of the data before computing the log likelihood.
-        hyper_background_noise
-            A model component which scales the background noise level of the data before computing the log likelihood.
-        use_hyper_scaling
-            If false, the scaling of the background sky and noise are not performed irrespective of the model components
-            themselves.
         preload_overwrite
             If a `Preload` object is input this is used instead of the preloads stored as an attribute in the analysis.
-        profiling_dict
+        run_time_dict
             A dictionary which times functions called to fit the model to data, for profiling.
 
         Returns
@@ -368,11 +258,10 @@ class AnalysisInterferometer(AnalysisDataset):
         return FitInterferometer(
             dataset=self.dataset,
             tracer=tracer,
-            hyper_background_noise=hyper_background_noise,
-            use_hyper_scaling=use_hyper_scaling,
             settings_pixelization=self.settings_pixelization,
             settings_inversion=self.settings_inversion,
             preloads=preloads,
+            run_time_dict=run_time_dict,
         )
 
     @property
@@ -404,7 +293,7 @@ class AnalysisInterferometer(AnalysisDataset):
              A log likelihood cap which is applied in a stochastic model-fit to give improved error and posterior
              estimates.
         """
-        instance = self.instance_with_associated_hyper_images_from(instance=instance)
+        instance = self.instance_with_associated_adapt_images_from(instance=instance)
         tracer = self.tracer_via_instance_from(instance=instance)
 
         if not tracer.has(cls=aa.Pixelization):
@@ -418,10 +307,6 @@ class AnalysisInterferometer(AnalysisDataset):
         ):
             return
 
-        hyper_background_noise = self.hyper_background_noise_via_instance_from(
-            instance=instance
-        )
-
         settings_pixelization = (
             self.settings_pixelization.settings_with_is_stochastic_true()
         )
@@ -429,12 +314,10 @@ class AnalysisInterferometer(AnalysisDataset):
         log_evidences = []
 
         for i in range(self.settings_lens.stochastic_samples):
-
             try:
                 log_evidence = FitInterferometer(
                     dataset=self.dataset,
                     tracer=tracer,
-                    hyper_background_noise=hyper_background_noise,
                     settings_pixelization=settings_pixelization,
                     settings_inversion=self.settings_inversion,
                     preloads=self.preloads,
@@ -453,6 +336,37 @@ class AnalysisInterferometer(AnalysisDataset):
 
         return log_evidences
 
+    def visualize_before_fit(self, paths: af.DirectoryPaths, model: af.Collection):
+        """
+        PyAutoFit calls this function immediately before the non-linear search begins.
+
+        It visualizes objects which do not change throughout the model fit like the dataset.
+
+        Parameters
+        ----------
+        paths
+            The PyAutoFit paths object which manages all paths, e.g. where the non-linear search outputs are stored,
+            visualization and the pickled objects used by the aggregator output by this function.
+        model
+            The PyAutoFit model object, which includes model components representing the galaxies that are fitted to
+            the imaging data.
+        """
+
+        visualizer = VisualizerInterferometer(visualize_path=paths.image_path)
+
+        visualizer.visualize_interferometer(dataset=self.interferometer)
+
+        if self.positions_likelihood is not None:
+            visualizer.visualize_image_with_positions(
+                image=self.dataset.dirty_image,
+                positions=self.positions_likelihood.positions,
+            )
+
+        visualizer.visualize_adapt_images(
+            adapt_galaxy_image_path_dict=self.adapt_galaxy_image_path_dict,
+            adapt_model_image=self.adapt_model_image,
+        )
+
     def visualize(self, paths: af.DirectoryPaths, instance, during_analysis):
         """
         Outputs images of the maximum log likelihood model inferred by the model-fit. This function is called
@@ -466,10 +380,10 @@ class AnalysisInterferometer(AnalysisDataset):
         - Images of the best-fit `FitInterferometer`, including the model-image, residuals and chi-squared of its fit
           to the imaging data.
 
-        - The hyper-images of the model-fit showing how the hyper galaxies are used to represent different galaxies in
+        - The adapt-images of the model-fit showing how the galaxies are used to represent different galaxies in
           the dataset.
 
-        - If hyper features are used to scale the noise, a `FitInterferometer` with these features turned off may be
+        - If adapt features are used to scale the noise, a `FitInterferometer` with these features turned off may be
           output, to indicate how much these features are altering the dataset.
 
         The images output by this function are customized using the file `config/visualize/plots.ini`.
@@ -487,10 +401,7 @@ class AnalysisInterferometer(AnalysisDataset):
             which may change which images are output.
         """
 
-        if os.environ.get("PYAUTOFIT_TEST_MODE") == "1":
-            return
-
-        instance = self.instance_with_associated_hyper_images_from(instance=instance)
+        instance = self.instance_with_associated_adapt_images_from(instance=instance)
 
         fit = self.fit_interferometer_via_instance_from(instance=instance)
 
@@ -532,21 +443,6 @@ class AnalysisInterferometer(AnalysisDataset):
 
         visualizer.visualize_contribution_maps(tracer=fit.tracer)
 
-        if visualizer.plot_fit_no_hyper:
-            fit = self.fit_interferometer_via_tracer_from(
-                tracer=fit.tracer,
-                hyper_background_noise=None,
-                use_hyper_scaling=False,
-                preload_overwrite=Preloads(use_w_tilde=False),
-            )
-
-            try:
-                visualizer.visualize_fit_interferometer(
-                    fit=fit, during_analysis=during_analysis, subfolders="fit_no_hyper"
-                )
-            except exc.InversionException:
-                pass
-
     def make_result(
         self,
         samples: af.SamplesPDF,
@@ -567,7 +463,7 @@ class AnalysisInterferometer(AnalysisDataset):
         - The non-linear search used to perform the model fit.
 
         The `ResultInterferometer` object contains a number of methods which use the above objects to create the max
-        log likelihood `Plane`, `FitInterferometer`, hyper-galaxy images,etc.
+        log likelihood `Plane`, `FitInterferometer`, adapt-galaxy images,etc.
 
         Parameters
         ----------
@@ -588,7 +484,7 @@ class AnalysisInterferometer(AnalysisDataset):
     def save_attributes_for_aggregator(self, paths: af.DirectoryPaths):
         """
          Before the non-linear search begins, this routine saves attributes of the `Analysis` object to the `pickles`
-         folder such that they can be load after the analysis using PyAutoFit's database and aggregator tools.
+         folder such that they can be loaded after the analysis using PyAutoFit's database and aggregator tools.
 
          For this analysis, it uses the `AnalysisDataset` object's method to output the following:
 
@@ -598,7 +494,7 @@ class AnalysisInterferometer(AnalysisDataset):
          - The settings associated with the inversion.
          - The settings associated with the pixelization.
          - The Cosmology.
-         - The hyper dataset's model image and galaxy images, if used.
+         - The adapt dataset's model image and galaxy images, if used.
 
          This function also outputs attributes specific to an imaging dataset:
 
@@ -630,3 +526,45 @@ class AnalysisInterferometer(AnalysisDataset):
                 "preload_sparse_grids_of_planes",
                 self.preloads.sparse_image_plane_grid_pg_list,
             )
+
+    def profile_log_likelihood_function(
+        self, instance: af.ModelInstance, paths: Optional[af.DirectoryPaths] = None
+    ) -> Tuple[Dict, Dict]:
+        """
+        This function is optionally called throughout a model-fit to profile the log likelihood function.
+
+        All function calls inside the `log_likelihood_function` that are decorated with the `profile_func` are timed
+        with their times stored in a dictionary called the `run_time_dict`.
+
+        An `info_dict` is also created which stores information on aspects of the model and dataset that dictate
+        run times, so the profiled times can be interpreted with this context.
+
+        The results of this profiling are then output to hard-disk in the `preloads` folder of the model-fit results,
+        which they can be inspected to ensure run-times are as expected.
+
+        Parameters
+        ----------
+        instance
+            An instance of the model that is being fitted to the data by this analysis (whose parameters have been set
+            via a non-linear search).
+        paths
+            The PyAutoFit paths object which manages all paths, e.g. where the non-linear search outputs are stored,
+            visualization and the pickled objects used by the aggregator output by this function.
+
+        Returns
+        -------
+        Two dictionaries, the profiling dictionary and info dictionary, which contain the profiling times of the
+        `log_likelihood_function` and information on the model and dataset used to perform the profiling.
+        """
+        run_time_dict, info_dict = super().profile_log_likelihood_function(
+            instance=instance,
+        )
+
+        info_dict["number_of_visibilities"] = self.dataset.visibilities.shape[0]
+        info_dict["transformer_cls"] = self.dataset.transformer.__class__.__name__
+
+        self.output_profiling_info(
+            paths=paths, run_time_dict=run_time_dict, info_dict=info_dict
+        )
+
+        return run_time_dict, info_dict
