@@ -14,7 +14,7 @@ class VisualizerInterferometer(Visualizer):
         self,
         fit: FitInterferometer,
         during_analysis: bool,
-        subfolders: str = "fit_interferometer",
+        subfolders: str = "fit_dataset",
     ):
         """
         Visualizes a `FitInterferometer` object, which fits an interferometer dataset.
@@ -45,7 +45,7 @@ class VisualizerInterferometer(Visualizer):
         mat_plot_1d = self.mat_plot_1d_from(subfolders=subfolders)
         mat_plot_2d = self.mat_plot_2d_from(subfolders=subfolders)
 
-        fit_interferometer_plotter = FitInterferometerPlotter(
+        fit_plotter = FitInterferometerPlotter(
             fit=fit,
             include_2d=self.include_2d,
             mat_plot_1d=mat_plot_1d,
@@ -53,15 +53,19 @@ class VisualizerInterferometer(Visualizer):
         )
 
         if should_plot("subplot_fit"):
-            fit_interferometer_plotter.subplot_fit_interferometer()
-            fit_interferometer_plotter.subplot_fit_dirty_images()
-            fit_interferometer_plotter.subplot_fit_real_space()
+            fit_plotter.subplot_fit()
 
-        fit_interferometer_plotter.figures_2d(
-            visibilities=should_plot("data"),
+        if should_plot("subplot_fit_dirty_images"):
+            fit_plotter.subplot_fit_dirty_images()
+
+        if should_plot("subplot_fit_real_space"):
+            fit_plotter.subplot_fit_real_space()
+
+        fit_plotter.figures_2d(
+            data=should_plot("data"),
             noise_map=should_plot("noise_map"),
             signal_to_noise_map=should_plot("signal_to_noise_map"),
-            model_visibilities=should_plot("model_data"),
+            model_data=should_plot("model_data"),
             residual_map_real=should_plot("residual_map"),
             chi_squared_map_real=should_plot("chi_squared_map"),
             normalized_residual_map_real=should_plot("normalized_residual_map"),
@@ -77,56 +81,64 @@ class VisualizerInterferometer(Visualizer):
             dirty_chi_squared_map=should_plot("chi_squared_map"),
         )
 
-        if not during_analysis:
+        if not during_analysis and should_plot("all_at_end_png"):
+            mat_plot_1d = self.mat_plot_1d_from(subfolders=path.join(subfolders, "end"))
+            mat_plot_2d = self.mat_plot_2d_from(subfolders=path.join(subfolders, "end"))
 
-            if should_plot("all_at_end_png"):
+            fit_plotter = FitInterferometerPlotter(
+                fit=fit,
+                include_2d=self.include_2d,
+                mat_plot_1d=mat_plot_1d,
+                mat_plot_2d=mat_plot_2d,
+            )
 
-                fit_interferometer_plotter.figures_2d(
-                    visibilities=True,
-                    noise_map=True,
-                    signal_to_noise_map=True,
-                    model_visibilities=True,
-                    residual_map_real=True,
-                    chi_squared_map_real=True,
-                    normalized_residual_map_real=True,
-                    residual_map_imag=True,
-                    chi_squared_map_imag=True,
-                    normalized_residual_map_imag=True,
-                    dirty_image=True,
-                    dirty_noise_map=True,
-                    dirty_signal_to_noise_map=True,
-                    dirty_model_image=True,
-                    dirty_residual_map=True,
-                    dirty_normalized_residual_map=True,
-                    dirty_chi_squared_map=True,
-                )
+            fit_plotter.figures_2d(
+                data=True,
+                noise_map=True,
+                signal_to_noise_map=True,
+                model_data=True,
+                residual_map_real=True,
+                chi_squared_map_real=True,
+                normalized_residual_map_real=True,
+                residual_map_imag=True,
+                chi_squared_map_imag=True,
+                normalized_residual_map_imag=True,
+                dirty_image=True,
+                dirty_noise_map=True,
+                dirty_signal_to_noise_map=True,
+                dirty_model_image=True,
+                dirty_residual_map=True,
+                dirty_normalized_residual_map=True,
+                dirty_chi_squared_map=True,
+            )
 
-            if should_plot("all_at_end_fits"):
+            plane_index_max = len(fit.tracer.planes) - 1
 
-                mat_plot_2d = self.mat_plot_2d_from(
-                    subfolders=path.join("fit_interferometer", "fits"), format="fits"
-                )
+            fit_plotter.figures_2d_of_planes(
+                plane_index=plane_index_max, plane_image=True
+            )
 
-                fit_interferometer_plotter = FitInterferometerPlotter(
-                    fit=fit, include_2d=self.include_2d, mat_plot_2d=mat_plot_2d
-                )
+        if not during_analysis and should_plot("all_at_end_fits"):
+            mat_plot_2d = self.mat_plot_2d_from(
+                subfolders=path.join("fit_dataset", "fits"), format="fits"
+            )
 
-                fit_interferometer_plotter.figures_2d(
-                    visibilities=True,
-                    noise_map=True,
-                    signal_to_noise_map=True,
-                    model_visibilities=True,
-                    residual_map_real=True,
-                    chi_squared_map_real=True,
-                    normalized_residual_map_real=True,
-                    residual_map_imag=True,
-                    chi_squared_map_imag=True,
-                    normalized_residual_map_imag=True,
-                    dirty_image=True,
-                    dirty_noise_map=True,
-                    dirty_signal_to_noise_map=True,
-                    dirty_model_image=True,
-                    dirty_residual_map=True,
-                    dirty_normalized_residual_map=True,
-                    dirty_chi_squared_map=True,
-                )
+            fit_plotter = FitInterferometerPlotter(
+                fit=fit, include_2d=self.include_2d, mat_plot_2d=mat_plot_2d
+            )
+
+            fit_plotter.figures_2d(
+                dirty_image=True,
+                dirty_noise_map=True,
+                dirty_signal_to_noise_map=True,
+                dirty_model_image=True,
+                dirty_residual_map=True,
+                dirty_normalized_residual_map=True,
+                dirty_chi_squared_map=True,
+            )
+
+            plane_index_max = len(fit.tracer.planes) - 1
+
+            fit_plotter.figures_2d_of_planes(
+                plane_index=plane_index_max, plane_image=True
+            )
