@@ -86,7 +86,7 @@ from autogalaxy.interferometer.plot.fit_interferometer_plotters import (
     FitInterferometerPlotter,
 )
 from autogalaxy.plane.plot.plane_plotters import PlanePlotter
-from autogalaxy.galaxy.plot.hyper_galaxy_plotters import HyperPlotter
+from autogalaxy.galaxy.plot.adapt_plotters import AdaptPlotter
 
 from autolens.point.plot.point_dataset_plotters import PointDatasetPlotter
 from autolens.point.plot.point_dataset_plotters import PointDictPlotter
