@@ -1,3 +1,5 @@
+from typing import Dict, Optional
+
 import autogalaxy as ag
 
 from autolens.point.point_dataset import PointDataset
@@ -19,17 +21,20 @@ except ModuleNotFoundError:
 
 class FitPointDataset:
     def __init__(
-        self, point_dataset: PointDataset, tracer: Tracer, point_solver: PointSolver
+        self,
+        point_dataset: PointDataset,
+        tracer: Tracer,
+        point_solver: PointSolver,
+        run_time_dict: Optional[Dict] = None,
     ):
-
         self.point_dataset = point_dataset
+        self.tracer = tracer
+        self.run_time_dict = run_time_dict
 
         point_profile = tracer.extract_profile(profile_name=point_dataset.name)
 
         try:
-
             if isinstance(point_profile, ag.ps.PointSourceChi):
-
                 self.positions = FitPositionsSource(
                     name=point_dataset.name,
                     positions=point_dataset.positions,
@@ -39,7 +44,6 @@ class FitPointDataset:
                 )
 
             else:
-
                 self.positions = FitPositionsImage(
                     name=point_dataset.name,
                     positions=point_dataset.positions,
@@ -55,7 +59,6 @@ class FitPointDataset:
             raise exc.FitException from e
 
         try:
-
             self.flux = FitFluxes(
                 name=point_dataset.name,
                 fluxes=point_dataset.fluxes,
@@ -65,15 +68,21 @@ class FitPointDataset:
             )
 
         except exc.PointExtractionException:
-
             self.flux = None
 
     @property
-    def log_likelihood(self) -> float:
+    def model_obj(self):
+        return self.tracer
 
+    @property
+    def log_likelihood(self) -> float:
         log_likelihood_positions = (
             self.positions.log_likelihood if self.positions is not None else 0.0
         )
         log_likelihood_flux = self.flux.log_likelihood if self.flux is not None else 0.0
 
         return log_likelihood_positions + log_likelihood_flux
+
+    @property
+    def figure_of_merit(self) -> float:
+        return self.log_likelihood
