@@ -1,3 +1,5 @@
+import os
+
 import autofit as af
 import autogalaxy as ag
 
@@ -29,13 +31,13 @@ class AnalysisQuantity(ag.AnalysisQuantity, AnalysisLensing):
 
         This Analysis class is used for model-fits which fit derived quantity of galaxies, for example their
         convergence, potential or deflection angles, to another model for that quantity. For example, one could find
-        the `EllPowerLaw` mass profile model that best fits the deflection angles of an `EllNFW` mass profile.
+        the `PowerLaw` mass profile model that best fits the deflection angles of an `NFW` mass profile.
 
         The `func_str` input defines what quantity is fitted, it corresponds to the function of the model `Plane`
         objects that is called to create the model quantity. For example, if `func_str="convergence_2d_from"`, the
         convergence is computed from each model `Plane`.
 
-        This class stores the settings used to perform the model-fit for certain components of the model (e.g. the 
+        This class stores the settings used to perform the model-fit for certain components of the model (e.g. the
         Cosmology used for the analysis).
 
         Parameters
@@ -113,6 +115,9 @@ class AnalysisQuantity(ag.AnalysisQuantity, AnalysisLensing):
             which may change which images are output.
         """
 
+        if os.environ.get("PYAUTOFIT_TEST_MODE") == "1":
+            return
+
         fit = self.fit_quantity_for_instance(instance=instance)
 
         visualizer = VisualizerQuantity(visualize_path=paths.image_path)
@@ -127,7 +132,7 @@ class AnalysisQuantity(ag.AnalysisQuantity, AnalysisLensing):
 
     def make_result(
         self,
-        samples: af.PDFSamples,
+        samples: af.SamplesPDF,
         model: af.Collection,
         sigma=1.0,
         use_errors=True,
