@@ -20,6 +20,7 @@ from autoarray.inversion.inversion.interferometer import (
 from autoarray.operators import transformer_util as transformer
 from autogalaxy.analysis import model_util as model
 from autogalaxy.util import error_util as error
-from autogalaxy.util import plane_util as plane
+from autogalaxy.plane import plane_util as plane
+from autogalaxy.analysis import chaining_util as chaining
 
 from autolens.lens import ray_tracing_util as ray_tracing
